//
// game.cpp
// 
// Simple illustration of a player-controlled camera.
//

#define VERSION 1.6

// Engine includes
#include "DisplayManager.h"
#include "GameManager.h"
#include "LogManager.h"
#include "WorldManager.h"

// Game includes
#include "Camera.h"
#include "Rock.h"

int main(int argc, char *argv[]) {

  // Start up Game Manager.
  if (GM.startUp())  {
    LM.writeLog("Error starting game manager!");
    GM.shutDown();
    return 0;
  }

  // Set world boundary and view.
  df::Box boundary = WM.getBoundary();
  df::Box view = WM.getView();
  df::Vector corner(0.0f, 0.0f);
  df::Box new_boundary(corner, 
		       boundary.getHorizontal()*8.0f,
		       boundary.getVertical()*8.0f);
  WM.setBoundary(new_boundary); // New boundary 8x bigger.
  corner.setX(new_boundary.getHorizontal()/2.0f - view.getHorizontal()/2.0f);
  corner.setY(new_boundary.getVertical()/2.0f - view.getVertical()/2.0f);
  view.setCorner(corner); // View centered in world.
  WM.setView(view);
  df::Vector new_slack(0.75f, 0.75f); 
  WM.setViewSlack(new_slack); // 75% slack on edge.

  // Splash screen
  df::splash();

  // Create Camera object to move the view.
  new Camera;

  // Create some rocks for decoration.
  for (int i=0; i<1000; i++)
    new Rock;

  // Run game (this blocks until the game loop is over).
  GM.run();

  // Shut everything down.
  GM.shutDown();
}

